Welcome to pysdic's documentation!
=========================================================================================

Description of the package
--------------------------

Python Stereo Digital Image Correlation Toolbox.

Contents
--------

The documentation is divided into the following sections:

- **Installation**: This section describes how to install the package.
- **API Reference**: This section contains the documentation of the package's API.
- **Usage**: This section contains the documentation of how to use the package.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   ./installation
   ./api
   ./usage


Author
------

The package ``pysdic`` was created by the following authors:

- Artezaru <artezaru.github@proton.me>

You can access the package and the documentation with the following URL:

- **Git Plateform**: https://github.com/Artezaru/pysdic.git
- **Online Documentation**: https://Artezaru.github.io/pysdic

License
-------

Please refer to the [LICENSE] file for the license of the package.
